from django.db import models
from django.contrib.auth.models import User

GENDER_CHOICES = (('M', "Male"),
                  ('F', 'Female'))

PROFESSION_CHOICES = (('S', 'Student'),
                      ('F', 'Faculty'),
                      ('P', 'Professional'))


class Profile(models.Model):
    """ A model to hold extra information about the user.
    """

    user = models.ForeignKey(User, unique=True)
    gender = models.CharField(max_length=1, choices=GENDER_CHOICES)
    profession = models.CharField(max_length=1, choices=PROFESSION_CHOICES)
    affiliated_to = models.CharField(max_length=100, verbose_name="College/Company")
    interests = models.CharField(max_length=100, verbose_name="Fields of Interest", 
                                 help_text="Ex: Python, Image Processing, Bio Informatics etc.")

    activation_key = models.CharField(max_length=30, unique=True)

class Event(models.Model):
    """ A model for the workshop information.
    """

    key = models.CharField(max_length=10, unique=True)

    title = models.CharField(max_length=100)
    description = models.TextField()
    start_date = models.DateField(help_text="YYYY-MM-DD")
    stop_date = models.DateField(help_text="YYYY-MM-DD")
    attendees = models.ManyToManyField(User, related_name="%(class)s_attendees")
    organizers = models.ManyToManyField(User, related_name="%(class)s_organizers")

    feedback_open = models.BooleanField()
    quiz_open = models.BooleanField()

    def __unicode__(self):

        return self.title
